"use client";

import { useEffect, useState } from "react";
import { Card } from "@/components/ui/card";
import { School } from "@/types/school";
import { Search, MapPin, GraduationCap } from "lucide-react";
import { getSuggestions } from "@/lib/api/schools";

interface SearchSuggestionsProps {
  query: string;
  onSelect: (suggestion: string) => void;
}

export default function SearchSuggestions({ query, onSelect }: SearchSuggestionsProps) {
  const [suggestions, setSuggestions] = useState<string[]>([]);
  const [isLoading, setIsLoading] = useState(false);

  useEffect(() => {
    const fetchSuggestions = async () => {
      if (!query) return;
      setIsLoading(true);
      try {
        const results = await getSuggestions(query);
        setSuggestions(results);
      } catch (error) {
        console.error("Failed to fetch suggestions:", error);
      } finally {
        setIsLoading(false);
      }
    };

    fetchSuggestions();
  }, [query]);

  if (!suggestions.length && !isLoading) return null;

  return (
    <Card className="absolute top-full left-0 right-0 mt-2 p-2 shadow-lg z-50">
      {isLoading ? (
        <div className="p-4 text-center text-muted-foreground">
          Loading suggestions...
        </div>
      ) : (
        <ul className="space-y-1">
          {suggestions.map((suggestion, index) => (
            <li key={index}>
              <button
                className="w-full px-4 py-2 text-left hover:bg-muted rounded-md flex items-center gap-2"
                onClick={() => onSelect(suggestion)}
              >
                <Search className="h-4 w-4 text-muted-foreground" />
                <span>{suggestion}</span>
              </button>
            </li>
          ))}
        </ul>
      )}
    </Card>
  );
}